summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorDieter Plaetinck <dieter@plaetinck.be>2009-07-23 19:32:35 +0200
committerDieter Plaetinck <dieter@plaetinck.be>2009-07-23 19:32:35 +0200
commitc0b16a498cae06666e61d6913fe3c402b77a3242 (patch)
tree209506563d8e4f637e1153b9cc744120f0a79da7 /src
parent402c82ba540388593371271733bd3565a702d6ff (diff)
rename FTP install to NET install (FS#14587)
Diffstat (limited to 'src')
-rw-r--r--src/core/libs/lib-pacman.sh12
-rw-r--r--src/core/libs/lib-ui-interactive.sh14
-rw-r--r--src/core/procedures/base2
-rw-r--r--src/core/procedures/interactive2
4 files changed, 15 insertions, 15 deletions
diff --git a/src/core/libs/lib-ui-interactive.sh b/src/core/libs/lib-ui-interactive.sh
index acbd50f..e68c999 100644
--- a/src/core/libs/lib-ui-interactive.sh
+++ b/src/core/libs/lib-ui-interactive.sh
@@ -30,7 +30,7 @@ interactive_configure_system()
#TODO: only need to do this once. check 'ended_ok worker configure_system' is not good because this could be done already even if worker did not exit 0
# /etc/pacman.d/mirrorlist
# add installer-selected mirror to the top of the mirrorlist
- if [ "$var_PKG_SOURCE_TYPE" = "ftp" -a "${var_SYNC_URL}" != "" ]; then
+ if [ "$var_PKG_SOURCE_TYPE" = "net" -a "${var_SYNC_URL}" != "" ]; then
debug 'PROCEDURE' "Adding choosen mirror (${var_SYNC_URL}) to ${var_TARGET_DIR}/$var_MIRRORLIST"
mirrorlist=`awk "BEGIN { printf(\"# Mirror used during installation\nServer = "${var_SYNC_URL}"\n\n\") } 1 " "${var_TARGET_DIR}/$var_MIRRORLIST"`
echo "$mirrorlist" > "${var_TARGET_DIR}/$var_MIRRORLIST" #TODO: test this, this may not work
@@ -980,12 +980,12 @@ interactive_select_source()
var_SYNC_URL=
ask_option no "Source selection" "Please select an installation source" required \
- "1" "CD-ROM or OTHER SOURCE" \
- "2" "FTP/HTTP" || return 1
+ "cd" "CD-ROM or OTHER SOURCE" \
+ "net" "NET (FTP/HTTP)" || return 1
case $ANSWER_OPTION in
- "1") var_PKG_SOURCE_TYPE="cd" ;;
- "2") var_PKG_SOURCE_TYPE="ftp" ;;
+ "cd") var_PKG_SOURCE_TYPE="cd" ;;
+ "net") var_PKG_SOURCE_TYPE="net" ;;
esac
if [ "$var_PKG_SOURCE_TYPE" = "cd" ]; then
@@ -997,7 +997,7 @@ interactive_select_source()
fi
echo "Using CDROM for package installation" >$LOG
else
- TITLE="Arch Linux FTP/HTTP Installation"
+ TITLE="Arch Linux NET (FTP/HTTP) Installation"
notify "If you wish to load your ethernet modules manually, please do so now in an another terminal."
fi
return 0
@@ -1050,7 +1050,7 @@ interactive_get_editor() {
select_source_extras_menu ()
{
while true; do
- ask_option no "FTP Installation" "Make sure the network is ok and you've selected a mirror before continuing the installer" required \
+ ask_option no "NET (HTTP/FTP) Installation" "Make sure the network is ok and you've selected a mirror before continuing the installer" required \
"1" "$worker_runtime_network_title" \
"2" "$worker_select_mirror_title" \
"3" "Return to Main Menu" || return 1
diff --git a/src/core/procedures/base b/src/core/procedures/base
index 1c5156d..fb7a60f 100644
--- a/src/core/procedures/base
+++ b/src/core/procedures/base
@@ -69,7 +69,7 @@ worker_select_source ()
var_PKG_SOURCE_TYPE='cd'
var_FILE_URL="file:///src/core/pkg"
var_SYNC_URL= # optional, points to a repository string something like ftp://ftp.belnet.be/mirror/archlinux.org/$repo/os/i686 (eg the same format as what you find in /etc/pacman.conf)
- # if you override to use ftp (or ask user and he chooses ftp) don't forget to configure the network and to select_mirrors
+ # if you override var_PKG_SOURCE_TYPE to 'net' (or ask user and he chooses ftp) don't forget to configure the network and to select_mirrors
}
diff --git a/src/core/procedures/interactive b/src/core/procedures/interactive
index 3cd535e..61fe90e 100644
--- a/src/core/procedures/interactive
+++ b/src/core/procedures/interactive
@@ -64,7 +64,7 @@ mainmenu()
"8" "Exit Install"
case $ANSWER_OPTION in
"1")
- execute worker select_source; ret=$?; [ $ret -eq 0 -a "$var_PKG_SOURCE_TYPE" = ftp ] && execute worker select_source_extras_menu
+ execute worker select_source; ret=$?; [ $ret -eq 0 -a "$var_PKG_SOURCE_TYPE" = net ] && execute worker select_source_extras_menu
[ $ret -eq 0 ] && execute worker runtime_packages && NEXTITEM=2 ;;
"2")
diff --git a/src/core/libs/lib-pacman.sh b/src/core/libs/lib-pacman.sh
index 19e2eca..3932640 100644
--- a/src/core/libs/lib-pacman.sh
+++ b/src/core/libs/lib-pacman.sh
@@ -9,7 +9,7 @@ assure_pacman_static ()
[ -f /usr/bin/pacman.static ] && PACMAN_STATIC=/usr/bin/pacman.static
if [ "$PACMAN_STATIC" = "" ]; then
cd /tmp
- if [ "$var_PKG_SOURCE_TYPE" = "ftp" ]; then
+ if [ "$var_PKG_SOURCE_TYPE" = "net" ]; then
echo "Downloading pacman..."
wget $PKGARG/pacman*.pkg.tar.gz
if [ $? -gt 0 ]; then
@@ -30,12 +30,12 @@ assure_pacman_static ()
}
# taken from the quickinst script. cd/ftp code merged together
target_write_pacman_conf ()
{
PKGFILE=/tmp/packages.txt
echo "[core]" >/tmp/pacman.conf
- if [ "$var_PKG_SOURCE_TYPE" = "ftp" ]
+ if [ "$var_PKG_SOURCE_TYPE" = "net" ]
then
wget $PKG_SOURCE/packages.txt -O /tmp/packages.txt || die_error " Could not fetch package list from server"
echo "Server = $PKGARG" >>/tmp/pacman.conf
@@ -48,7 +48,7 @@ target_write_pacman_conf ()
fi
mkdir -p $var_TARGET_DIR/var/cache/pacman/pkg /var/cache/pacman &>/dev/null
rm -f /var/cache/pacman/pkg &>/dev/null
- [ "$var_PKG_SOURCE_TYPE" = "ftp" ] && ln -sf $var_TARGET_DIR/var/cache/pacman/pkg /var/cache/pacman/pkg &>/dev/null
+ [ "$var_PKG_SOURCE_TYPE" = "net" ] && ln -sf $var_TARGET_DIR/var/cache/pacman/pkg /var/cache/pacman/pkg &>/dev/null
[ "$var_PKG_SOURCE_TYPE" = "cd" ] && ln -sf $PKGARG /var/cache/pacman/pkg &>/dev/null
}
@@ -60,7 +60,7 @@ target_write_pacman_conf ()
# returns: 1 on error
target_prepare_pacman() {
[ "$var_PKG_SOURCE_TYPE" = "cd" ] && local serverurl="${var_FILE_URL}"
- [ "$var_PKG_SOURCE_TYPE" = "ftp" ] && local serverurl="${var_SYNC_URL}"
+ [ "$var_PKG_SOURCE_TYPE" = "net" ] && local serverurl="${var_SYNC_URL}"
[ -z "$1" ] && repos=core
[ -n "$1" ] && repos="$@"
@@ -73,7 +73,7 @@ EOF
for repo in $repos
do
#TODO: this is a VERY, VERY dirty hack. we fall back to ftp for any non-core repo because we only have core on the CD. also user maybe didn't pick a mirror yet
if [ "$repo" != core ]
then
add_pacman_repo target ${repo} "Include = $var_MIRRORLIST"
@@ -30,12 +30,12 @@ assure_pacman_static ()
}
-# taken from the quickinst script. cd/ftp code merged together
+# taken from the quickinst script. cd/net code merged together
target_write_pacman_conf ()
{
@@ -73,7 +73,7 @@ EOF
for repo in $repos
do
- #TODO: this is a VERY, VERY dirty hack. we fall back to ftp for any non-core repo because we only have core on the CD. also user maybe didn't pick a mirror yet
+ #TODO: this is a VERY, VERY dirty hack. we fall back to net for any non-core repo because we only have core on the CD. also user maybe didn't pick a mirror yet
if [ "$repo" != core ]
then